===========
pypercolate
===========

.. image:: https://travis-ci.org/andsor/pypercolate.svg?branch=master
   :target: https://travis-ci.org/andsor/pypercolate
   :alt: Testing status

.. image:: https://coveralls.io/repos/andsor/pypercolate/badge.svg?branch=master&service=github
   :target: https://coveralls.io/github/andsor/pypercolate?branch=master
   :alt: Test coverage

.. image:: https://landscape.io/github/andsor/pypercolate/master/landscape.svg?style=flat
   :target: https://landscape.io/github/andsor/pypercolate/master
   :alt: Code Health

.. image:: https://img.shields.io/pypi/v/percolate.svg
  :target: https://pypi.python.org/pypi/percolate
  :alt: PyPI version
  
.. image:: https://img.shields.io/pypi/pyversions/percolate.svg
  :target: https://pypi.python.org/pypi/percolate
  :alt: Python versions
  
.. image:: https://img.shields.io/pypi/status/percolate.svg
  :target: https://pypi.python.org/pypi/percolate
  :alt: Status

.. image:: https://img.shields.io/pypi/l/percolate.svg
  :target: http://pypercolate.readthedocs.org/en/stable/license.html
  :alt: License

.. image:: https://img.shields.io/github/release/andsor/pypercolate.svg
  :target: https://github.com/andsor/pypercolate/releases/latest
  :alt: Latest release on GitHub
  
.. image:: https://img.shields.io/github/tag/andsor/pypercolate.svg
  :target: https://github.com/andsor/pypercolate/tags
  :alt: Latest tag on GitHub

.. image:: https://img.shields.io/github/issues/andsor/pypercolate.svg
  :target: https://github.com/andsor/pypercolate/issues
  :alt: Open Issues on GitHub

.. image:: https://readthedocs.org/projects/pypercolate/?badge=latest
  :target: http://pypercolate.readthedocs.org/en/latest
  :alt: Documentation

.. image:: https://readthedocs.org/projects/pypercolate/?badge=stable
  :target: http://pypercolate.readthedocs.org/en/stable
  :alt: Documentation

.. image:: https://zenodo.org/badge/6089/andsor/pypercolate.svg
   :target: https://zenodo.org/badge/latestdoi/6089/andsor/pypercolate
   :alt: Citation

Scientific Python package for Monte-Carlo simulation of percolation on graphs

* **Documentation**: http://pypercolate.readthedocs.org
* **Setup**: http://pypercolate.readthedocs.org/en/stable/setup.html
